==> gorilla-notes-0.4.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$Preview.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$Preview=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&
obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?
ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=void 0;var _react=function(obj){if(obj&&
obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=
obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index"));global=function(_Component){function Preview(){if(!(this instanceof Preview))throw new TypeError("Cannot call a class as a function");var _this=arguments.length;for(var args=Array(_this),_key=0;_key<_this;_key++)args[_key]=arguments[_key];_this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"mounted",!1);_defineProperty(_assertThisInitialized(_this),
"state",{image:null});return _this}_inherits(Preview,_Component);var _super=_createSuper(Preview);_createClass(Preview,[{key:"componentDidMount",value:function(){this.mounted=!0;this.fetchImage(this.props)}},{key:"componentDidUpdate",value:function(prevProps){var _this$props=this.props,light=_this$props.light;prevProps.url===_this$props.url&&prevProps.light===light||this.fetchImage(this.props)}},{key:"componentWillUnmount",value:function(){this.mounted=!1}},{key:"fetchImage",value:function(_ref){var _this2=
this,url=_ref.url;_ref=_ref.light;if("string"===typeof _ref)this.setState({image:_ref});else return this.setState({image:null}),window.fetch("https://noembed.com/embed?url\x3d".concat(url)).then(function(response){return response.json()}).then(function(data){data.thumbnail_url&&_this2.mounted&&(data=data.thumbnail_url.replace("height\x3d100","height\x3d480"),_this2.setState({image:data}))})}},{key:"render",value:function(){var _this$props2=this.props,onClick=_this$props2.onClick;_this$props2=_this$props2.playIcon;
var image=this.state.image,flexCenter={display:"flex",alignItems:"center",justifyContent:"center"};image=_objectSpread({width:"100%",height:"100%",backgroundImage:image?"url(".concat(image,")"):void 0,backgroundSize:"cover",backgroundPosition:"center",cursor:"pointer"},flexCenter);flexCenter=_objectSpread({background:"radial-gradient(rgb(0, 0, 0, 0.3), rgba(0, 0, 0, 0) 60%)",borderRadius:"64px",width:"64px",height:"64px"},flexCenter);flexCenter=_react["default"].createElement("div",{style:flexCenter,
className:"react-player__shadow"},_react["default"].createElement("div",{style:{borderStyle:"solid",borderWidth:"16px 0 16px 26px",borderColor:"transparent transparent transparent white",marginLeft:"7px"},className:"react-player__play-icon"}));return _react["default"].createElement("div",{style:image,className:"react-player__preview",onClick},_this$props2||flexCenter)}}]);return Preview}(_react.Component);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$Preview.js.map

==> gorilla-notes-0.5.0-20201016.181256-9.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$Preview.js <==
shadow$provide.module$node_modules$react_player$lib$Preview=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&
obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?
ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=void 0;var _react=function(obj){if(obj&&
obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=
obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index"));global=function(_Component){function Preview(){if(!(this instanceof Preview))throw new TypeError("Cannot call a class as a function");var _this=arguments.length;for(var args=Array(_this),_key=0;_key<_this;_key++)args[_key]=arguments[_key];_this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"mounted",!1);_defineProperty(_assertThisInitialized(_this),
"state",{image:null});return _this}_inherits(Preview,_Component);var _super=_createSuper(Preview);_createClass(Preview,[{key:"componentDidMount",value:function(){this.mounted=!0;this.fetchImage(this.props)}},{key:"componentDidUpdate",value:function(prevProps){var _this$props=this.props,light=_this$props.light;prevProps.url===_this$props.url&&prevProps.light===light||this.fetchImage(this.props)}},{key:"componentWillUnmount",value:function(){this.mounted=!1}},{key:"fetchImage",value:function(_ref){var _this2=
this,url=_ref.url;_ref=_ref.light;if("string"===typeof _ref)this.setState({image:_ref});else return this.setState({image:null}),window.fetch("https://noembed.com/embed?url\x3d".concat(url)).then(function(response){return response.json()}).then(function(data){data.thumbnail_url&&_this2.mounted&&(data=data.thumbnail_url.replace("height\x3d100","height\x3d480"),_this2.setState({image:data}))})}},{key:"render",value:function(){var _this$props2=this.props,onClick=_this$props2.onClick;_this$props2=_this$props2.playIcon;
var image=this.state.image,flexCenter={display:"flex",alignItems:"center",justifyContent:"center"};image=_objectSpread({width:"100%",height:"100%",backgroundImage:image?"url(".concat(image,")"):void 0,backgroundSize:"cover",backgroundPosition:"center",cursor:"pointer"},flexCenter);flexCenter=_objectSpread({background:"radial-gradient(rgb(0, 0, 0, 0.3), rgba(0, 0, 0, 0) 60%)",borderRadius:"64px",width:"64px",height:"64px"},flexCenter);flexCenter=_react["default"].createElement("div",{style:flexCenter,
className:"react-player__shadow"},_react["default"].createElement("div",{style:{borderStyle:"solid",borderWidth:"16px 0 16px 26px",borderColor:"transparent transparent transparent white",marginLeft:"7px"},className:"react-player__play-icon"}));return _react["default"].createElement("div",{style:image,className:"react-player__preview",onClick:onClick},_this$props2||flexCenter)}}]);return Preview}(_react.Component);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$Preview.js.map
